# numworks_env

`numworks_env` is a Python package that emulates the **NumWorks calculator environment** and its modules.  
It allows you to experiment with NumWorks code on your PC, giving a decent simulation of the calculator’s behavior, while letting you know **what you can use or not** compared to the real device.

---

**Don't understand English?**  
Check out the [README in French](README_fr.md) for full documentation.

---

## Installation

You can install `numworks_env` using `pip`

```
pip install numworks_env
```

## Usage

See [NumWorks python docs](https://www.numworks.com/manual/python)